California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 021 - EXPANDS LOCAL GOVERNMENTS' AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405723 | ISSUES PAC OF APARTMENT ASSOCIATION OF GREATER LOS ANGELES - NO ON 21 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1418902 | YES ON 21 - RENTERS AND HOMEOWNERS UNITED TO KEEP FAMILIES IN THERI HOMES, SPONSORED BY AIDS HEALTHCARE FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406018 | NO ON 21 - CALIFORNIANS FOR AFFORDABLE HOUSING, SPONSORED BY THE CALIFORNIA RENTAL HOUSING ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1426377 | NO ON PROP 21 - CALIFORNIANS TO PROTECT AFFORDABLE HOUSING - A COALITION OF HOUSING ADVOCATES, RENTERS, BUSINESSES, TAXPAYERS, AND VETERANS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283587 | MULTI-COUNTY PROPERTY RIGHTS PAC, NO ON PROPOSITION 21, SPONSORED BY APARTMENT ASSOCIATION OF ORANGE COUNTY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1433352 | ENOUGH IS ENOUGH, NO NEW TAXES! | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1421884 | NO ON PROP 21: CALIFORNIANS FOR RESPONSIBLE HOUSING, A COALITION OF SENIORS, VETERANS, AFFORDABLE HOUSING ADVOCATES, LABOR & SOCIAL JUSTICE ORGANIZATIONS, SPONSORED BY CALIFORNIA APARTMENT ASSOCIATION | OPPOSE